==> sl-cia-2.0.97.tgz: package/lib/new-diff-service.js <==
﻿var Promise = require('promise'),
    util = require('util'),
    consoleFileLogger = require("./sl-logger.js").consoleFileLogger;

function NewDiffService(cfg, needle, logger) {
    this.submitMapping = function (mapping) {
        var promise = new Promise(function (resolve, reject) {
            var opts = {
                json: true,
                compressed: true
            };
            if (cfg.proxy) //http://user:pass@proxy.server.com:3128
                opts.proxy = cfg.proxy;

            var route = cfg.isValidToken ? "/v2/agents/buildmapping" : "/v1/buildmapping";
            var url = cfg.server + route;
            var log = logger? logger.child({className: "NewDiffService", methodName: "submitMapping"}) : consoleFileLogger("NewDiffService");
            log.debug('Submitting build mapping: ' + JSON.stringify(mapping, null, "\t"));

            needle.post(url, mapping, opts, function (err, resp, body) {
                if (!err && resp.statusCode >= 300) {
                    err = new Error("Server returned status code " + resp.statusCode + ": " + resp.body);
                }
                if (err) {
                    log.info("Submitted with error: " + err.toString());
                    reject(err);
                }
                else {
                    log.info("Submitted successfully");
                    resolve(resp.body);
                }
            });
        });

        return promise;
    }
}

module.exports.NewDiffService = NewDiffService;

==> sl-cia-2.0.199.tgz: package/lib/new-diff-service.js <==
﻿var Promise = require('promise'),
    util = require('util'),
    consoleFileLogger = require("./sl-logger.js").consoleFileLogger;

function NewDiffService(cfg, needle, logger) {
    this.submitMapping = function (mapping) {
        var promise = new Promise(function (resolve, reject) {
            var opts = {
                json: true,
                compressed: true
            };
            if (cfg.proxy) //http://user:pass@proxy.server.com:3128
                opts.proxy = cfg.proxy;

            var apiVersion = cfg.isUseBuildMappingV3 ? "/v3":"/v2"
            var route = cfg.isValidToken ? apiVersion + "/agents/buildmapping" : "/v1/buildmapping";
            var url = cfg.server + route;
            var log = logger? logger.child({className: "NewDiffService", methodName: "submitMapping"}) : consoleFileLogger("NewDiffService");
            log.info('Submitting build mapping to url:"' + url + '"');
            log.debug('Submitting build mapping: ' + JSON.stringify(mapping, null, "\t"));

            needle.post(url, mapping, opts, function (err, resp, body) {
                if (!err && resp.statusCode >= 300) {
                    err = new Error("Server returned status code " + resp.statusCode + ": " + resp.body);
                }
                if (err) {
                    log.info("Submitted with error: " + err.toString());
                    reject(err);
                }
                else {
                    log.info("Submitted successfully");
                    resolve(resp.body);
                }
            });
        });

        return promise;
    }
}

module.exports.NewDiffService = NewDiffService;
